<?php
/**
# SNS 단추 달기 (텍스트큐브 끼우개)
# 만든이 : 팥알 ( https://pat.im/816 | pat@pat.im )
# 마지막으로 고친 때 : 2020. 3. 24.
**/

define('SNS_icons_PLUGIN_VERSION', '1.34');

/* *** <head>~</head> 안에 본문에 넣을 단추의 CSS를 끼워넣는다. *** */
function SNS_icons_header_content($target) {

	global $configVal, $entry;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	$context = Model_Context::getInstance();
	$blog_id = $context->getProperty('blog.id');
	$blogURL = $context->getProperty('uri.blog');
	$blog_title = $context->getProperty('blog.title');
	$post_title = $entry['title'];
	//$defaultURL = $context->getProperty('uri.default');
	$serviceURL = $context->getProperty('uri.service');

	$entry_id = isset($entry['id']) ? $entry['id'] : 0;
	$entry['content'] = preg_replace('/\[##_[^|#\]]+_##\]/','',$entry['content']); // 본문의 치환자를 없앰
	$beginning_length = isset($data['beginning_length']) ? $data['beginning_length'] : 150;
	$beginning = UTF8::lessenAsEm(htmlspecialchars(trim(removeAllTags(stripHTML($entry['content'])))), $beginning_length);
	if(empty($beginning)) $beginning = htmlspecialchars(trim($context->getProperty('blog.description')));
	
	$header = CRLF;

	if(!empty($data['meta_type'])) {
		$type = 'article';
		$header .= '<meta property="og:type" content="'.$type.'" />'.CRLF;
	}
	
	if(!empty($data['meta_url'])) {
		$url = SNS_icons_post_url($entry_id);
		$header .= '<meta property="og:url" content="'.$url.'" />'.CRLF;
	}

	if(!empty($data['meta_blog_title']) && !empty($blog_title)) {
		$blog_title = htmlspecialchars($blog_title);
		$header .= '<meta property="og:site_name" content="'.$blog_title.'"/>'.CRLF;
	}

	if(!empty($data['meta_post_title'])) {
		if(empty($post_title)) $post_title = $blog_title;
		$encoded_post_title = htmlspecialchars($post_title);
		$header .= '<meta property="og:title" content="'.$encoded_post_title.'" />'.CRLF;
		//$header .= '<meta name="title" content="'.$post_title.'" />'.CRLF;
	}

	if(!empty($data['meta_description'])) {
		if(!empty($beginning)) {
			$header .= '<meta property="og:description" content="'.$beginning.'" />'.CRLF;
			$header .= '<meta name="Description" content="'.$beginning.'" />'.CRLF;
		}
	}

	if(!empty($data['image_src'])) {		// 글에 붙인 그림 하나를 미리보기 그림(thumbnail)로 알린다.
		if(preg_match('/\[##_featured_image\|([^|]*)\.(gif|jpg|jpeg|png|bmp)(\|width="([0-9]+)"\s*height="([0-9]+)")?_##\]/i', $entry['content'], $matches)) {
			// 앞세울 그림이 [##_featured_image|???.gif_##] 꼴로 지정됨
			$img_link = $serviceURL.'/attach/'.$blog_id.'/'.$matches[1].'.'.$matches[2];
			if(!empty($matches[4])) $header .= '<meta property="og:image:width" content="'.$matches[4].'" />'.CRLF;
			if(!empty($matches[5])) $header .= '<meta property="og:image:height" content="'.$matches[5].'" />'.CRLF;
		}
		else if(preg_match('/\[##_(1R|1L|1C|2C|3C|iMazing|Gallery)\|([^|]*)\.(gif|jpg|jpeg|png|bmp)\|.*_##\]/i', $entry['content'], $matches)) {
			// 치환자로 들어간 첫 그림
			$img_link = $serviceURL.'/attach/'.$blog_id.'/'.$matches[2].'.'.$matches[3];
		}
		else if(preg_match('/\<img[^>]+?src=("(.*?)"|\'(.*?)\').*\>/i', $entry['content'], $matches)) {
			// <img> 태그로 들어간 첫 그림
			$img_link = $matches[2];
			if(substr($img_link,0,7) != 'http://' && substr($img_link,0,8) != 'https://' && substr($img_link,0,2) == '//') {
				$img_link = $serviceURL.(subsur($img_link,0,1) == '/' ? '' : '/').$img_link;
			}
		}

		if(isset($img_link)) $header .= '<meta property="og:image" content="'.$img_link.'" />'.CRLF;
	}

	$header .= '<style>'.CRLF;
	$header .= '@media screen,print {'.CRLF;
	$position_array = array('onTop', 'onBottom', 'onSidebar', 'onTag');
	foreach($position_array as $position) {
		if($data[$position.'_css'] && ($position=='onSidebar' || $position=='onTag' || $data[$position]))
			$header .= SNS_icons_stylesheet($position).CRLF;
	}
	$header .= '}'.CRLF;
	$header .= '</style>'.CRLF;
	$target = $target.$header;

	return $target;
}

// </body> 앞에 넣을 내용
function SNS_icons_footer_content($target) {	

	global $configVal, $entries, $entry;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	$footer = '';
	if( ($data['onTop'] && $data['onTop_more']) || ($data['onBottom'] && $data['onBottom_more']) || $data['onTag_more'] || $data['onSidebar_more']) {
		$count = isset($entries) ? count($entries) : 0;
		for($i=0; $i<$count; ++$i) {
			$entry_id = isset($entries[$i]['id']) ? $entries[$i]['id'] : 0;
			$footer .= more_script($entries[$i]['id']);
		}
	}
	
	if( $data['onTag_more'] || $data['onSidebar_more'] || $data['onTag_bookmark'] || $data['onSidebar_bookmark'] || ($data['onTop'] && ($data['onTop_bookmark'] || $data['onTop_more'])) || ($data['onBottom'] && ($data['onBottom_bookmark'] || $data['onBottom_more'])) ) {
		$footer .= '<script><!--
function favorites(title,url){
	
	agt = navigator.userAgent.toLowerCase();
	if(navigator.appName == "Microsoft Internet Explorer" || (navigator.appName == "Netscape" && new RegExp("Trident/.*rv:([0-9]{1,}[\.0-9]{0,})").exec(navigator.userAgent) != null)){window.external.AddFavorite(url,title);}
	else {alert(\'즐겨찾기에 넣으려면 Ctrl+D를 누르세요.\');}
}
//-->
</script>'.CRLF;
	}

	return $target.$footer;
}

// 더 보기 창을 나타내는 자바스크립트
function more_script($entry_id) {

	global $configVal, $pluginURL, $pluginName, $entry;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	$x_item_num = $data['more_x_item_num'] > 0 ? $data['more_x_item_num'] : 2;		// 더 보기 가로 항목 수
	$sidename_width = $data['more_item_name_width'] > 0 ? $data['more_item_name_width'] : 100;		// 더 보기 항목 이름 가로 폭
	$icon_size = 16;		// 더 보기 쪽그림 크기
	$icon_wrap_margin_side = 6;		// 쪽그림 좌우 여백
	$sidename_margin_left = 4;		// 이름 좌우 여백
	$width = ($icon_size + $icon_wrap_margin_side*2 + $sidename_width + $sidename_margin_left) * $x_item_num;

	$border = 3;		// 더 보기 창 테두리 굵기
	
	$context = Model_Context::getInstance();
	//$defaultURL = $context->getProperty('uri.default');
	$serviceURL = $context->getProperty('uri.service');
	$blogURL = $context->getProperty('uri.blog');
	$post_title = isset($entry['title']) ? $entry['title'] : '';

	$icon_path = empty($data['icon_path']) || $data['icon_path'] == 'http://' ? $serviceURL.$pluginURL.'/images' : $data['icon_path'];
	$icon_path .= '/icons_16x16.png';

	$innerHTML = '<span class=\\"more_layer_title\\" style=\\"padding:6px 5px; float:left; position:relative;\\">글 보내기</span>';
	$innerHTML .= '<span class=\\"more_layer_close\\" onclick=\\"SNS_icons_more_layer'.$entry_id.'(this.parentNode, this.parentNode.entry_id, this.parentNode.position_name);\\" style=\\"padding:6px 5px; position:relative; float:right; cursor:pointer; font-weight:bold;\\">닫기</span>';	

	$innerHTML .= '<div class=\\"SNS_more_icon_list\\" style=\\"clear:both;padding:3px 0; margin:0; text-align:left; line-height:1em; cursor:auto; background:#F0F0F0\\">';

	SNS_link_array($link, $entry_id);
	icon_name_array($icon_name_array);
	$j = -1;
	foreach($icon_name_array['category'] as $category) {
		++$j;
		if($category=='media_sharing' || $category=='more') continue;
		$i = -1;
		foreach($icon_name_array[$category]['name'] as $name) {
			++$i;
			if(empty($name)) continue;

			$sidename = $icon_name_array[$category][$name]['sidename'];
			if(is_null($sidename)) continue;
			
			$onclick = str_replace('"', '&quot;',$link[$name]['onclick']);
			$onclick .=  'SNS_icons_more_layer'.$entry_id.'(this.parentNode.parentNode, this.parentNode.parentNode.entry_id, this.parentNode.parentNode.position_name);';
			$innerHTML .= '<div class=\\"SNS_more_icon_wrap\\" onclick=\\"'.$onclick.'\\" onmouseover=\\"this.style.background=\'#ddc\';\\" onmouseout=\\"this.style.background=\'none\';\\" style=\\"font-size:12px; cursor:pointer; margin:0; padding:3px '.$icon_wrap_margin_side.'px; display:'.(strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") && preg_match("/MSIE (?P<version>\d+)/", $_SERVER['HTTP_USER_AGENT'], $browser) && $browser['version'] < 8 ? 'inline' : 'inline-block').';\\">';
			if($name=='bookmark') {
				//$innerHTML .= '<a href=\\"'.(strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox') ? SNS_icons_post_url($entry_id) : $link['bookmark']['link']).'\\" style=\\"color:#000;text-decoration:none;font-weight:normal;border:none;\\" title=\\"'.SNS_icons_post_title($entry_id).'\\" rel=\\"sidebar\\">';
				$innerHTML .= '<a href=\\"'.$link['bookmark']['link'].'\\" style=\\"color:#000;text-decoration:none;font-weight:normal;border:none;\\" title=\\"'.SNS_icons_post_title($entry_id).'\\" rel=\\"sidebar\\">';
			}
			else if(strtolower(substr($link[$name]['link'],0,10))=='javascript') {
				$innerHTML .= '<a href=\\"'.$link[$name]['link'].'\\" style=\\"color:#000;text-decoration:none;font-weight:normal;border:none;\\">';
			}
			$innerHTML .= '<span class=\\"'.$name.'\\" style=\\"padding:0; vertical-align:middle; display:inline-block; width:'.$icon_size.'px; height:'.$icon_size.'px; background: url(\''.$icon_path.'\') '.(-$i*16).'px '.(-$j*16).'px;\\"></span>';
			$innerHTML .= '<span style=\\"padding:0 0 0 '.$sidename_margin_left.'px; width:'.$sidename_width.'px; vertical-align:middle; text-align:left; display:inline-block;\\">'.$sidename.'</span>';
			if(strtolower(substr($link[$name]['link'],0,10))=='javascript') $innerHTML .= '</a>';
			$innerHTML .= '</div>';
		}
	}

	$innerHTML .= '</div>';		// icon_list
	$innerHTML .= '<span class=\\"SNS_icons_version\\" style=\\"margin:0; padding:4px; float:right; cursor:pointer;\\"><a href=\\"//pat.im/tag/SNS_icons\\" target=\\"_blank\\" style=\\"background:none;font-size:12px;font-weight:bold;color:#333;border:none;\\">v'.SNS_icons_PLUGIN_VERSION.'</a></span>';

	$content = CRLF;
	$content .= '<script>'.CRLF;
	$content .= '<!--'.CRLF;
	$content .= 'function SNS_icons_more_layer'.$entry_id.'(anchor, entry_id, icon_position) {'.CRLF;
	$content .= '	var layer = document.getElementById("SNS_icons_more_" + entry_id + "_" + icon_position);'.CRLF;
	$content .= '	var icon_div = document.getElementById("SNS_icons_" + icon_position + "_" + entry_id);'.CRLF;
	$content .= '	var more_icon_div = document.getElementById("more_icon_" + icon_position + "_" + entry_id);'.CRLF;

	if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') && preg_match('/MSIE (?P<version>\d+)/',$_SERVER['HTTP_USER_AGENT'],$browser) && $browser['version'] < 8) { // IE 7 이하
		$content .= ' layer.style.top = ( more_icon_div.offsetTop + more_icon_div.offsetHeight + getOffsetTop(more_icon_div.offsetParent) + '.$icon_size.'/2 ) + "px";'.CRLF;
		$content .= ' layer.style.left = ( more_icon_div.offsetLeft + getOffsetLeft(more_icon_div.offsetParent)'.CRLF;
	} else {	// IE 8 이상 또는 그밖의 웹 누비개
		$content .= '	layer.style.top = ( more_icon_div.offsetTop + more_icon_div.offsetHeight + '.$icon_size.'/2 ) + "px";'.CRLF;
		$content .= '	layer.style.left = ( more_icon_div.offsetLeft';
	}
	if($data['more_layer_horizontal_position'] == 'right') $content .= ($data['more_x_correction'] ? '+ ('.$data['more_x_correction'] : '').')) + "px";'.CRLF;
	else $content .= ' + more_icon_div.offsetWidth'.($data['more_x_correction'] ? ' + ('.$data['more_x_correction'].')' : '').'-'.($width+4).') + "px";'.CRLF;
	$content .= '	if(parseInt(layer.style.left) < 0) layer.style.left = 0 + "px";'.CRLF; // 더 보기 창이 화면 왼쪽 경계를 넘어갈 때 안쪽으로 붙임
	
	$content .= '	if(layer.style.display == "inline-block") {layer.style.display = "none";}'.CRLF;
	$content .= '	else if(layer.style.display == "none") {layer.style.display = "inline-block";}'.CRLF;
	$content .= '	else {'.CRLF;
	$content .= '		layer.entry_id = entry_id;'.CRLF;
	$content .= '		layer.position_name = icon_position;'.CRLF;
	$content .= '		layer.style.background = "#DDD";'.CRLF; //#F0F0F0
	$content .= '		layer.style.cursor = "move";'.CRLF;
	$content .= '		layer.style.border = "'.$border.'px #999 solid";'.CRLF;
	$content .= '		layer.style.color = "#000000";'.CRLF;
	$content .= '		layer.style.margin = "0";'.CRLF;
	$content .= '		layer.style.padding = "0 0 0 0";'.CRLF;
	$content .= '		layer.style.width = "'.$width.'px";'.CRLF;
	$content .= '		layer.style.position = "absolute";'.CRLF;
	$content .= '		layer.style.lineHeight = "1em";'.CRLF;
	$content .= '		layer.innerHTML = "'.$innerHTML.'";'.CRLF;	
	$content .= '		layer.style.display = "inline-block";'.CRLF;
	$content .= '
var layer_mousemove=0;
layer.addEventListener("mousedown", function(e){
	var targetObj=window.event? event.srcElement : e.target
	if(targetObj==layer || targetObj.className=="more_layer_title"){
		var x,y,offsetx,offsety;
		var evtObj=window.event? window.event : e;
		layer_mousemove=1;
		if(isNaN(parseInt(layer.style.left))) layer.style.left=0;
		if(isNaN(parseInt(layer.style.top))) layer.style.top=0;
		offsetx=parseInt(layer.style.left);
		offsety=parseInt(layer.style.top);
		x=evtObj.clientX;
		y=evtObj.clientY;
		if(evtObj.preventDefault) evtObj.preventDefault();
		window.addEventListener("mousemove", 
			function(e){
				if(layer_mousemove==1){
					var evtObj=window.event? window.event : e;
					layer.style.left=offsetx+evtObj.clientX-x+"px";
					layer.style.top=offsety+evtObj.clientY-y+"px";
					return false;
				}
		});
		window.addEventListener("mouseup", function(){layer_mousemove=0});
	}
});
//layer.ondragstart=function(){return false;};
//layer.onselectstart=function(){return false;};'.CRLF;
	$content .= '	}'.CRLF;
	$content .= '}'.CRLF;
	$content .= '//-->'.CRLF;
	$content .= '</script>'.CRLF;

	return $content;
}


/* *** 단추 자리에 맞추어 단추의 CSS 내용을 돌려 준다. *** */
function SNS_icons_stylesheet($position) {

	global $pluginURL, $configVal, $pluginName;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	if(empty($pluginURL)) $pluginURL = '/plugins/SNS_icons';

	$context = Model_Context::getInstance();
	//$defaultURL = $context->getProperty('uri.default');
	$serviceURL = $context->getProperty('uri.service');
	$blogURL = $context->getProperty('uri.blog');

	$type = $data[$position.'_type'];		// 단추 모양
	$align = $data[$position.'_align'];		// 가로 정렬
	$icon_type = $data[$position.'_type'] == 'text' ? $icon_type = 'button' : $icon_type = 'span';

	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_margin_top'], $margin_top);		// 여백의 크기와 단위를 뽑는다.
	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_margin_bottom'], $margin_bottom);
	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_margin_left'], $margin_left);
	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_margin_right'], $margin_right);
	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_icon_interval'], $icon_interval);
	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_icon_line_height'], $icon_line_height);
	preg_match('/(?P<size>\d+)($|(?P<unit>\w+))/', $data[$position.'_sidename_width'], $icon_sidename_width);

	if(empty($margin_top['unit'])) $margin_top['unit'] = 'px';
	if(empty($margin_bottom['unit'])) $margin_bottom['unit'] = 'px';
	if(empty($margin_left['unit'])) $margin_left['unit'] = 'px';
	if(empty($margin_right['unit'])) $margin_right['unit'] = 'px';
	if(empty($icon_interval['unit'])) $icon_interval['unit'] = 'px';
	if(empty($icon_line_height['unit'])) $icon_line_height['unit'] = 'px';
	if(empty($icon_sidename_width['unit'])) $icon_sidename_width['unit'] = 'px';

	if(empty($margin_top['size'])) $margin_top['size'] = '0';
	if(empty($margin_bottom['size'])) $margin_bottom['size'] = '0';
	if(empty($margin_left['size'])) $margin_left['size'] = '0';
	if(empty($margin_right['size'])) $margin_right['size'] = '0';
	if(empty($icon_interval['size'])) $icon_interval['unit'] = '0';
	if(empty($icon_line_height['size'])) $icon_line_height['unit'] = '0';
	if(empty($icon_sidename_width['size'])) $icon_sidename_width['unit'] = '0';

	if($align=='right') { $icon_margin_left = $icon_interval['size']; $icon_margin_right = 0;}		// 가로 정렬 방식에 맞게 단추 간격을 정한다.
	else if($align=='left') {$icon_margin_right = $icon_interval['size']; $icon_margin_left = 0;}
	else {
			$icon_margin_left = (int)($icon_interval['size']/2);
			$icon_margin_right = (int)($icon_interval['size']/2) + $icon_interval['size']%2;
	}

	$position_class = '.SNS_icons_'.$position;
	$header = $position_class.' {';
	if($align != 'none') $header .= 'text-align:'.$align.';';
	$header .= 'margin:'.$margin_top['size'].$margin_top['unit'].' '.$margin_right['size'].$margin_right['unit'].' '.$margin_bottom['size'].$margin_bottom['unit'].' '.$margin_left['size'].$margin_left['unit'].';';
	$header .= '}'.CRLF;
	
	preg_match('/(?P<width>\d+)x(?P<height>\d+)/', $type, $icon_size);

	$header .= $position_class.' .icon_wrap {';
	$header .= 'cursor:pointer;';
	if($icon_margin_left) $header .= 'margin-left:'.$icon_margin_left.$icon_interval['unit'].';';
	if($icon_margin_right) $header .= 'margin-right:'.$icon_margin_right.$icon_interval['unit'].';';
	if($data[$position.'_sidename_position'] == 'bottom') {
		$header .= 'display:inline-block;';
		$header .= 'vertical-align:top;';
		$header .= 'text-align:center;';
		if($icon_line_height['size']) $header .= 'margin-bottom:'.$icon_line_height['size'].$icon_line_height['unit'].' !important;';
	} else {
		$header .= 'width:'.$icon_size['width'].'px;';
		$header .= 'display:inline;';
	}
	$header .= '}'.CRLF;

	$header .= $position_class.' .icon_wrap a, '.$position_class.' .icon_wrap a:link, '.$position_class.' .icon_wrap a:visited {';
 	$header .= 'border:none;text-decoration:none;';
	$header .= '}'.CRLF;
	
	if($type == 'text') {		// 쪽그림이 없는 글 단추
		$header .= $position_class.' .icon_wrap {';
		$header .= 'display:inline;';
		$header .= '}';
		$header .= $position_class.' .icon_wrap '.$icon_type.' {';
		$header .= 'cursor:pointer;';
		$header .= 'display:inline;';
		if($icon_line_height['size']) $header .= 'margin-bottom:'.$icon_line_height['size'].$icon_line_height['unit'].' !important;';
		$header .= '}'.CRLF;
		return $header;
	}

	icon_name_array($icon_name_array);

	$icon_path = empty($data['icon_path']) || $data['icon_path'] == 'http://' ? $serviceURL.$pluginURL.'/images' : $data['icon_path'];
	$icon_path .= '/icons_'.$icon_size['width'].'x'.$icon_size['height'].'.png';
	$header .= $position_class.' .icon_wrap '.$icon_type.' {';
	$header .= 'background-image:url("'.$icon_path.'");';
	$header .= 'border:0;';
	if($data[$position.'_sidename_position'] == 'bottom') {
		$header .= 'display:block;';
		$header .= 'margin-left:auto;';
		$header .= 'margin-right:auto;';
	}	else {
		$header .= 'display:inline-block;';
		if($icon_line_height['size']) $header .= 'margin-bottom:'.$icon_line_height['size'].$icon_line_height['unit'].' !important;';
	}

	$header .= 'width:'.$icon_size['width'].'px;';
	$header .= 'height:'.$icon_size['height'].'px;';
	$header .= '}'.CRLF;
	
	if($data[$position.'_sidename_position'] != 'none' || !$data[$position.'_sidename_position']) {			// 쪽그림에 이름을 붙일 때
		$header .= $position_class.' span.sidename {';
		$header .= 'text-align:center;';		
		$header .= 'font:'.$data[$position.'_sidename_font_size'].'px dotum;';
		if($data[$position.'_sidename_font_color']) $header .= 'color:#'.$data[$position.'_sidename_font_color'].';';
		$header .= 'background:none;';
		if($icon_sidename_width['size']) $header .= 'width:'.$icon_sidename_width['size'].$icon_sidename_width['unit'].';';
		else $header .= 'width:auto;';

		if($data[$position.'_sidename_position'] == 'bottom') {
			$header .= 'height:auto;';
			$header .= 'padding-top:'.$data[$position.'_sidename_margin'].'px;';
		} else {
			$header .= 'display:inline-block;';
			$header .= 'padding-top:'.round(($icon_size['height']-$data[$position.'_sidename_font_size'])/2).'px;';
			$header .= 'padding-left:'.($data[$position.'_sidename_margin']).'px;';
			$header .= 'vertical-align:top;';
			$header .= 'text-align:left;';
		}
		$header .= '}';
	}

	if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE')) {
		preg_match('/MSIE (?P<version>\d+)/', $_SERVER['HTTP_USER_AGENT'], $browser);
		if($browser['version'] < 8) {		// IE 7 이하일 때
			$header .= $position_class.' .icon_wrap {';
			if($data[$position.'_sidename_position'] == 'bottom') {
				if($icon_sidename_width['size'] > $icon_size['width']) $header .= 'width:'.$icon_sidename_width['size'].$icon_sidename_width['unit'].' !important;';
				else $header .= 'width:'.$icon_size['width'].'px !important;';
			} else $header .= 'width:auto !important;';
			$header .= 'display:inline;';
			$header .= '}'.CRLF;
		}
	}

	$j = -1;
	foreach($icon_name_array['category'] as $category) {
		++$j;
		if($category=='media_sharing' || !isset($icon_name_array[$category]['name']) || !count($icon_name_array[$category]['name'])) continue;
		$i = 0;
		foreach($icon_name_array[$category]['name'] as $name) {
			if(!empty($name) && !empty($data[$position.'_'.$name])) {
				$header .= $position_class.' .icon_wrap .'.$name.' {';
				$header .= 'background-position:'.(-$i*$icon_size['width']).'px '.(-$j*$icon_size['height']).'px;';
				$header .= '}';
			}
			++$i;
		}
	}

	return $header;
}

/* *** 위치에 맞게 글 보내는 단추의 HTML 내용을 돌려 준다. *** */
function show_SNS_icons($position, $entry_id) {

	global $configVal, $pluginURL;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);			// 설정값이 없으면 기본값을 넣는다.

	$context = Model_Context::getInstance();
	$blog_id = $context->getProperty('blog.id');
	
	$DB_data = DBModel::getInstance();
	$DB_data->reset('Entries');
	$DB_data->setQualifier('blogid','eq',$blog_id);
	$DB_data->setQualifier('id','eq',$entry_id);
	$entry = $DB_data->getRow();
	$post_title = $entry['title'];

	$icon_type = $data[$position.'_type'] == 'text' ? $icon_type = 'button' : $icon_type = 'span';

	$content = '<div id="SNS_icons_'.$position.'_'.$entry_id.'" class="SNS_icons_'.$position.'"'.'>';

	SNS_link_array($link, $entry_id);
	icon_name_array($icon_name_array);
	foreach($icon_name_array['category'] as $category) {
		if($category=='media_sharing') continue;
		$i = -1;
		foreach($icon_name_array[$category]['name'] as $name) {
			++$i;
			if(empty($name)) continue;
			if(!$data[$position.'_'.$name] || !$link[$name]) continue;
			$balloon_name = $icon_name_array[$category][$name]['balloon_name'];
			$sidename = $icon_name_array[$category][$name]['sidename'];

			if($name == 'more') $onclick = 'javascript:SNS_icons_more_layer'.$entry_id.'(this,'.$entry_id.',\''.$position.'\');';
			else $onclick = $link[$name]['onclick'];
			$onclick = str_replace('"','&quot;',$onclick);

			$content .= '<div title="'.$balloon_name.'" class="icon_wrap icon_wrap_'.$name.'">';
			if($name=='bookmark') {
				//$content .= '<a href="'.(strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox') ? SNS_icons_post_url($entry_id) : $link['bookmark']['link'] ).'" title="'.SNS_icons_post_title($entry_id).'" rel="sidebar">';
				$content .= '<a href="'.$link['bookmark']['link'].'" title="'.SNS_icons_post_title($entry_id).'" rel="sidebar">';
			}
			else if(isset($link[$name]['link']) && strtolower(substr($link[$name]['link'],0,10))=='javascript') {
				$content .= '<a href="'.$link[$name]['link'].'">';
			}
			//else $content .= '<a onclick="'.$onclick.'" rel="external nofollow">';
			$content .= '<'.$icon_type.' class="'.$name.'" onclick="'.$onclick.'"';
			if($name == 'more') $content .= ' id="more_icon_'.$position.'_'.$entry_id.'"';
			$content .= '>';
			if($icon_type == 'button') $content .= '<span>'.$sidename.'</span>';
			$content .= '</'.$icon_type.'>';
			if($data[$position.'_sidename_position'] != 'none' && $icon_type != 'button') $content .= '<span class="sidename">'.$sidename.'</span>';
			if($name=='bookmark' || isset($link[$name]['link']) && strtolower(substr($link[$name]['link'],0,10))=='javascript') 
				$content .= '</a>';
			$content .= '</div>';
		}
	}

	$content .= '</div>'.CRLF;
	if($data[$position.'_more']) $content .=	'<div id="SNS_icons_more_'.$entry['id'].'_'.$position.'" style="z-index:1000000;"></div>'.CRLF;

	return $content;
}

function SNS_icons_post_url($entry_id) {	// 글 주소
	global $configVal;
	$data = Setting::fetchConfigVal($configVal);
	
	$context = Model_Context::getInstance();
	$blog_id = $context->getProperty('blog.id');
	$defaultURL = $context->getProperty('uri.default');
	$useEncodeURL = $context->getProperty('service.useEncodeURL');
	$useSloganOnPost = $context->getProperty('blog.useSloganOnPost');
	$useSSL = $context->getProperty('service.useSSL');
	
	$DB_data = DBModel::getInstance();
	$DB_data->reset('Entries');
	$DB_data->setQualifier('blogid','eq',$blog_id);
	$DB_data->setQualifier('id','eq',$entry_id);
	$entry = $DB_data->getRow();

	if($entry['id']) $post_url = $defaultURL.'/'.($useSloganOnPost && $data['post_url']==1 ? 'entry/'.URL::encode($entry['slogan'], $useEncodeURL) : $entry['id']);	// 글 주소
	else $post_url = ($useSSL ? 'https://' : 'http://').$_SERVER['HTTP_HOST'].($_SERVER['SERVER_PORT']=='80' || $_SERVER['SERVER_PORT']=='443' ? '' : ':'.$_SERVER['SERVER_PORT']).($_SERVER['REQUEST_URI']=='/' ? '' : $_SERVER['REQUEST_URI']);
	return $post_url;
}

function SNS_icons_post_title($entry_id) {	// 글 제목
	global $configVal;
	$data = Setting::fetchConfigVal($configVal);

	$context = Model_Context::getInstance();
	$blog_id = $context->getProperty('blog.id');
	$blog_title = $context->getProperty('blog.title');

	$DB_data = DBModel::getInstance();
	$DB_data->reset('Entries');
	$DB_data->setQualifier('blogid','eq',$blog_id);
	$DB_data->setQualifier('id','eq',$entry_id);
	$entry = $DB_data->getRow();

	$search = array("'", '"');
	$replace = array('＇', '＂');
	//$replace = array('&#8216;$1&#8217;', '&#8220;$1&#8221;');
	$post_title = str_replace($search, $replace, $entry['title']);

	if($data['blog_title_position'] == 'fore') $post_title = $blog_title.(empty($data['blog_title_division']) ? ' :: ' : $data['blog_title_division']).$post_title;
	else if($data['blog_title_position'] == 'back') $post_title = $post_title.(empty($data['blog_title_division']) ? ' :: ' : $data['blog_title_division']).$blog_title;
	
	return $post_title;
}
	
function SNS_link_array(&$link, $entry_id) {	// 글에 맞는 단추들의 연결 고리를 건낸다.

	global $configVal, $pluginURL;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);			// 설정값이 없으면 기본값을 넣는다.

	$context = Model_Context::getInstance();
	$defaultURL = $context->getProperty('uri.default');
	$serviceURL = $context->getProperty('uri.service');
	$blog_id = $context->getProperty('blog.id');
	$blog_title = $context->getProperty('blog.title');
	$blogURL = $context->getProperty('uri.blog');
	$baseURL = $context->getProperty('uri.base');
	$blog_address = preg_replace('/(http|https):\/\//i', '', $defaultURL);
	$encoded_blog_address = rawurlencode($blog_address);
	$useEncodeURL = $context->getProperty('service.useEncodeURL');
	$useSloganOnPost = $context->getProperty('blog.useSloganOnPost');
	
	$DB_data = DBModel::getInstance();
	$DB_data->reset('Entries');
	$DB_data->setQualifier('blogid','eq',$blog_id);
	$DB_data->setQualifier('id','eq',$entry_id);
	$entry = $DB_data->getRow();

	$original_url = SNS_icons_post_url($entry_id);
	$encoded_original_url = rawurlencode($original_url);
	
	if($data['short_url'] == 'other' && !empty($data['other_url'])) {
		if($entry['id']) $url = $data['other_url'].(substr($data['other_url'],-1,1)=='/' ? '' : '/').($useSloganOnPost && $data['post_url']==1 ? 'entry/'.URL::encode($entry['slogan'], $useEncodeURL) : $entry['id']);		// 글 주소
		else $url = $data['other_url'].(substr($data['other_url'],-1,1)=='/' ? '' : '/').$_SERVER['REQUEST_URI'];
	} else $url = $original_url;

	$encoded_url = rawurlencode($url);
	$encoded_blog_title = rawurlencode($blog_title);

	$search = array("'", '"');
	$replace = array('＇', '＂');
	$blog_title = str_replace($search, $replace, $blog_title);

	$title = SNS_icons_post_title($entry_id);
	$encoded_title = rawurlencode($title);
	
	if(isset($data['beginning_length']) && $data['beginning_length']) $beginning_length = $data['beginning_length'];
	else $beginning_length = 150;

	// 이 플러그인의 치환자가 본문에 들어 있을 때에 글이 나오지 않는 오류를 막는다.
	$entry['content'] = preg_replace('/\[##_[^|#\]]+_##\]/', '', $entry['content']);

	$text = trim(html_entity_decode(htmlspecialchars_decode(UTF8::lessenAsEm(removeAllTags(stripHTML($entry['content'])), $beginning_length))));
	$encoded_text = rawurlencode($text);
	
	// 전달할 쪽글에서 스크립트에 문제를 일으킬 수 있거나 넣을 수 없는 문자들을 바꾼다.
	$search = array('?', '::', '<', '>');
	$replace = array('？', '∷', '〈', '〉');
	$bookmark_script_title = str_replace($search, $replace, $title);		// 즐겨찾기 스크립트에 들어갈 제목
	$search = array('(', ')');
	$replace = array('（', '）');
	$script_title = str_replace($search, $replace, $title);		// 링크나우에 들어갈 제목

	if(isset($entry['id'])) $tags_array = getTags($blog_id, $entry['id']);		// 글의 꼬리표를 따온다.
	else $tags_array = array();
	$tags = '';
	foreach($tags_array as $tag) $tags .= $tag['name'].',';
	if(substr($tags,-1) == ',') $tags = substr($tags,0,-1);
	$encoded_tags = rawurlencode($tags);

	$link['twitter']['link'] = 'https://twitter.com/intent/tweet?original_referer='.$encoded_url.'&amp;text='.$encoded_title.'&amp;url='.$encoded_url;
	if(!empty($data['twitter_via_id'])) $link['twitter']['link'] .= '&amp;via='.$data['twitter_via_id'];
	$link['facebook']['link'] = 'https://www.facebook.com/sharer.php?t='.$encoded_title.'&amp;u='.$encoded_original_url;
	$link['google_plus']['link'] = 'https://plus.google.com/share?url='.$encoded_original_url.'&amp;t='.$encoded_title;
  $link['kakaostory']['link'] = 'https://story.kakao.com/share?url='.$encoded_url;
	//$link['kakaostory']['link'] = 'storylink://posting?post='./*urlencode('[').$encoded_blog_title.urlencode('] ').*/$encoded_title.urlencode(' ').$encoded_url.'&amp;appid='.$encoded_blog_address.'&amp;appver=1.0&amp;apiver=1.0&amp;appname='.$encoded_blog_title;
	////$link['cyworld']['link'] = 'http://csp.cyworld.com/bi/bi_recommend_pop.php?url='.$encoded_original_url.'&amp;t='.$encoded_title;
	//$link['cyworld']['link'] = 'http://csp.cyworld.com/share/?u='.$encoded_original_url;
	
	$link['band']['link'] = 'https://www.band.us/plugin/share?body='.$encoded_title.'%0A'.$encoded_url.'&amp;route='.$encoded_blog_address;
	$link['tumblr']['link'] = 'https://www.tumblr.com/share?v=3&amp;u='.$encoded_url.'&amp;t='.$encoded_title;
	//$link['myspace']['link'] = 'http://www.myspace.com/Modules/PostTo/Pages/?l=1&amp;u='.$encoded_original_url.'&amp;t='.$encoded_title;
	$link['pinterest']['link'] = 'javascript:void((function(){var e=document.createElement(\'script\');e.setAttribute(\'charset\',\'UTF-8\');e.setAttribute(\'src\',\'https://assets.pinterest.com/js/pinmarklet.js?r=\'+Math.random()*99999999);document.body.appendChild(e)})());';

  $link['linkedin']['link'] = 'https://www.linkedin.com/shareArticle?mini=true&url='.$encoded_original_url.'&title='.$encoded_title.'&ro=false&summary='.$encoded_text.'&source=';
	//$link['linknow']['link'] = 'https://www.linknow.kr/?go=send_wall&amp;data='.urlencode('{"title":"'.$script_title.' '.$url.'"}');

	$link['blogger']['link'] = 'https://www.blogger.com/blog_this.pyra?t&u='.$encoded_original_url.'&n='.$encoded_title.'&pli=1';
	$link['naver_blog']['link'] = 'http://blog.naver.com/LinkShare.nhn?url='.$encoded_original_url.'&amp;title='.$encoded_title;

	$link['evernote']['link'] = 'https://www.evernote.com/clip.action?url='.$encoded_url.'&amp;title='.$encoded_title;
	$link['naver_memo']['link'] = 'https://memo.naver.com/plugin/view.nhn?linkUrl='.$encoded_url.'&amp;content='.$title.'%0A'.urlencode('출처: ').$encoded_blog_title.'&amp;linkDisplayText='.$encoded_title;

	$link['bookmark']['link'] = 'javascript:favorites(\''.$bookmark_script_title.'\', \''.$encoded_original_url.'\')';
	$link['google_bookmarks']['link'] = 'https://www.google.com/bookmarks/mark?op=add&amp;bkmk='.$encoded_original_url.'&amp;title='.$encoded_title.'&amp;labels='.$encoded_tags.'&amp;annotation='.$encoded_text;
	//$link['naver_bookmark']['link'] = 'https://bookmark.naver.com/post?m=post&amp;ns=1&amp;title='.$encoded_title.'&amp;url='.$encoded_original_url;
	$link['yahoo_bookmarks']['link'] = 'https://bookmarks.yahoo.com/toolbar/savebm?opener=tb&amp;t='.$encoded_title.'&amp;d='.$encoded_text.'&amp;u='.$encoded_original_url;
	$link['margarin']['link'] = 'http://mar.gar.in/post/popup_post/?qTitle=%'.$encoded_title.'&amp;qURL='.$encoded_original_url;
	//$link['delicious']['link'] = 'https://www.delicious.com/save?v=5&amp;noui&amp;jump=close&amp;url='.$encoded_original_url.'&amp;title='.$encoded_title;
	//$link['digg']['link'] = 'https://digg.com/submit?phase=2&amp;url='.$encoded_original_url.'&amp;title='.$encoded_title.'&amp;bodytext='.$encoded_text;

	//$link['hanrss']['link'] = 'http://www.hanrss.com/bookmarks/add_link.qst?url='.$encoded_original_url.'&amp;title='.$encoded_title;

	$mail_text = rawurlencode($title."\n".$original_url."\n".$text);
	$link['mail']['link'] = 'mailto:?subject='.$encoded_title.'&amp;body='.$mail_text;
	$link['gmail']['link'] = 'https://mail.google.com/mail/?ui=2&view=cm&fs=1&tf=1&su='.$encoded_title.'&amp;body='.$mail_text;
	//$link['hotmail']['link'] = 'https://hotmail.com/secure/start?action=compose&subject='.$encoded_title.'&amp;body='.$mail_text;
	$link['yahoo_mail']['link'] = 'https://compose.mail.yahoo.com/dc/launch?action=compose&amp;To=&Subj='.$encoded_title.'&amp;Body='.$mail_text;

	$link['kakaotalk']['link'] = 'kakaolink://sendurl?msg='.$encoded_title.'&amp;url='.$encoded_url.'&amp;appid='.$encoded_blog_address.'&amp;appver=2.0&amp;type=link&amp;appname='.$encoded_blog_title;
	$link['nateon']['link'] = 'http://api.nateon.nate.com/web/note/SendNote.do?msg='.$encoded_title.'&lurl='.$encoded_url;
	$link['line']['link'] = 'https://timeline.line.me/social-plugin/share?url='.$encoded_url;
	//$link['mypeople']['link'] = 'http://mypeople.daum.net/mypeople/web/share.do?prefix='.$encoded_title.'&amp;link='.$encoded_url.'&amp;source_id=21&amp;callback=postdone';

	icon_name_array($icon_name_array);
	foreach($icon_name_array['category'] as $category) {
		if($category=='media_sharing') continue;
		$i = -1;
		foreach($icon_name_array[$category]['name'] as $name) {
			++$i;
			if(empty($name)) continue;
			$balloon_name = $icon_name_array[$category][$name]['balloon_name'];
			$sidename = $icon_name_array[$category][$name]['sidename'];
			$window_width = 780;
			$window_height = 510;
			if($name=='yozm' || $name=='me2day' || $name=='connect' || $name=='margarin' || $name=='evernote') $window_width = 980;
			//if($name=='mypeople') $window_height = 550;

			if(isset($link[$name]['link'])) {
				if(strtolower(substr($link[$name]['link'],0,10))=='javascript') $onclick = '';
				else if($data['short_url'] != 'none' && $data['short_url'] != 'other' && preg_match('/^(twitter|me2day|yozm)/',$name) && !($name=='twitter' && $data['twitter_link'] == 2))
					$onclick = 'window.open(\''.$serviceURL.$pluginURL.'/'.'convert_to_shortURL.php?shortURL_domain='.$data['short_url'].'&amp;linkURL='.urlencode($link[$name]['link']).'&amp;longURL='.$encoded_url.'&amp;width='.$window_width.'&amp;height='.$window_height.'\', \''.$name.'\', \'width='.$window_width.', height='.$window_height.', resizable=1, scrollbars=1\');';
				else $onclick = 'window.open(\''.$link[$name]['link'].'\', \''.$name.'\', \'width='.$window_width.', height='.$window_height.', resizable=1, scrollbars=1\');';
			}

			$link[$name]['onclick'] = $onclick;
		}
	}
}


/* ***	치환자 [##_SNS_icons_##]에 단추를 넣는다. *** */
function show_icons_onTag($target) {
	global $configVal, $entry;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	$tagContent = show_SNS_icons('onTag', $entry['id']);
	return $tagContent;
}


/* ***	옆막대에 글 보내는 단추를 넣는다. *** */
function show_icons_onSidebar($parameter) {
	global $configVal, $entry;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	$sidebarContent = show_SNS_icons('onSidebar', $entry['id']);
	return $sidebarContent;
}


/* ***	본문에 글 보내기 단추를 넣는다. *** */
function show_icons_onContent($target, $mother) {
	global $configVal, $entry;
	$data = Setting::fetchConfigVal($configVal);
	if(is_null($data)) SNS_icons_initial_config($data);

	$position_array = array('onTop', 'onBottom');
	foreach($position_array as $position)
		if(isset($data[$position]) && $data[$position]) $content[$position] = show_SNS_icons($position, $mother);
		else $content[$position] = '';
	
	return $content['onTop'].$target.$content['onBottom'];
}


/* *** 환경설정값이 없으면 기본값으로 채운다. *** */
function SNS_icons_initial_config(&$data) {
	$data['beginning_length'] = 150;
	$data['short_url'] = 'none';
	$data['other_url'] = '';
	$data['post_url'] = 1;
	$data['twitter_link'] = 1;
	$data['more_layer_horizontal_position'] = 'left';

	$data['meta_type'] = 0;
	$data['meta_blog_title'] = 0;
	$data['meta_post_title'] = 0;
  $data['meta_description'] = 0;
  $data['image_src'] = 0;

	$position_array = array('onTop', 'onBottom', 'onSidebar', 'onTag');
	icon_name_array($icon_name_array);

	foreach($position_array as $position) {
		$data[$position.'_css'] = 1;
		$i=0;
		foreach($icon_name_array['category'] as $category) {
			$j=0;
			foreach($icon_name_array[$category]['name'] as $name) {
				if(!$i && $j++<3) $data[$position.'_'.$name] = 1;
			}
			++$i;
		}
		$data[$position] = 0;
		$data[$position.'_more'] = 1;
		$data[$position.'_type'] = '24x24';
		$data[$position.'_align'] = 'right';
		$data[$position.'_icon_interval'] = '5';
		$data[$position.'_icon_line_height'] = '5';
		$data[$position.'_sidename_position'] = 'none';
		$data[$position.'_sidename_font_size'] = '11';
		$data[$position.'_sidename_color'] = '';
		$data[$position.'_sidename_margin'] = '5';
		$data[$position.'_sidename_width'] = '0';
		$data[$position.'_margin_top'] = '10';
		$data[$position.'_margin_bottom'] = '10';
		$data[$position.'_margin_left'] = '0';
		$data[$position.'_margin_right'] = '0';
	}
	
	$data['onBottom'] = 1;
}

/* *** SNS와 즐겨찾기 누리집의 이름을 넣는다. *** */
function icon_name_array(&$icon_name_array) {
	$icon_name_array['category'] = array('SNS1', 'SNS2', 'messenger', 'media_sharing', 'blog', 'RSS', 'bookmark', 'mail', 'more');

	$icon_name_array['SNS1']['name'] = array('twitter', 'facebook', 'google_plus', 'tumblr', 'linkedin', 'pinterest');
	$SNS1_sidename_array = array('twitter'=>'트위터', 'facebook'=>'페이스북', 'google_plus'=>'구글+', 'tumblr'=>'텀블러', 'linkedin'=>'링크드인', 'pinterest'=>'핀터레스트');
	$SNS1_balloon_name_array = array('twitter'=>'트위터에 보내기', 'facebook'=>'페이스북에 보내기', 'google_plus'=>'구글+에 보내기', 'tumblr'=>'텀블러에 보내기', 'linkedin'=>'링크드인에 보내기', 'pinterest'=>'핀터레스트로 보내기');

	$icon_name_array['SNS2']['name'] = array('kakaostory', 'band'/*, 'linknow', 'cyworld'*/);
	$SNS2_sidename_array = array('kakaostory'=>'카카오스토리', 'band'=>'밴드', 'linknow'=>'링크나우', 'cyworld'=>'싸이월드', );
	$SNS2_balloon_name_array = array('kakaostory'=>'카카오스토리로 보내기', 'band'=>'밴드로 보내기', 'linknow'=>'링크나우로 보내기', 'cyworld'=>'싸이월드에 보내기');

	$icon_name_array['messenger']['name'] = array('kakaotalk', 'nateon', 'line');
	$messenger_sidename_array = array('kakaotalk'=>'카카오톡', 'nateon'=>'네이트온', 'line'=>'라인');
	$messenger_balloon_name_array = array('kakaotalk'=>'카카오톡으로 보내기', 'nateon'=>'네이트온으로 보내기', 'line'=>'라인으로 보내기');

	$icon_name_array['blog']['name'] = array('blogger', 'naver_blog');
	$blog_sidename_array = array('blogger'=>'블로거', 'naver_blog'=>'네이버 블로그');
	$blog_balloon_name_array = array('blogger'=>'블로거로 보내기', 'naver_blog'=>'네이버 블로그로 보내기');

	$icon_name_array['RSS']['name'] = array('');
	//$RSS_sidename_array = array('hanrss'=>'한RSS');
	//$RSS_balloon_name_array = array('hanrss'=>'한RSS에 넣기');
	
	$icon_name_array['bookmark']['name'] = array('bookmark', 'google_bookmarks', 'margarin', '', ''/*'digg'*/, 'evernote', 'naver_memo');
	$bookmark_sidename_array = array('bookmark'=>'즐겨찾기', 'google_bookmarks'=>'구글 즐겨찾기', 'margarin'=>'마가린', 'delicious'=>'딜리셔스' , 'digg'=>'디그', 'evernote'=>'에버노트', 'naver_memo'=>'네이버 메모');
	$bookmark_balloon_name_array = array('bookmark'=>'즐겨찾기에 넣기', 'google_bookmarks'=>'구글 즐겨찾기에 넣기', 'margarin'=>'마가린 바르기', 'delicious'=>'딜리셔스로 보내기', 'digg'=>'디그로 보내기', 'evernote'=>'에버노트로 보내기', 'naver_memo'=>'네이버 메모로 보내기');

	$icon_name_array['mail']['name'] = array('mail', 'gmail', 'yahoo_mail');
	$mail_sidename_array = array('mail'=>'전자우편', 'gmail'=>'구글 편지', 'hotmail'=>'호트메일', 'yahoo_mail'=>'야후 편지');
	$mail_balloon_name_array = array('mail'=>'편지 보내기', 'gmail'=>'구글 편지로 보내기', 'hotmail'=>'호트메일로 보내기', 'yahoo_mail'=>'야후 편지로 보내기');

	$icon_name_array['more']['name'] = array('more');
	$more_sidename_array = array('more'=>'더 보기');
	$more_balloon_name_array = array('more'=>'더 보기');

	foreach($icon_name_array['SNS1']['name'] as $name)
		if(!empty($name)) $icon_name_array['SNS1'][$name] = array('balloon_name' => $SNS1_balloon_name_array[$name], 'sidename' => $SNS1_sidename_array[$name]);

	foreach($icon_name_array['SNS2']['name'] as $name)
		if(!empty($name)) $icon_name_array['SNS2'][$name] = array('balloon_name' => $SNS2_balloon_name_array[$name], 'sidename' => $SNS2_sidename_array[$name]);

	foreach($icon_name_array['bookmark']['name'] as $name)
		if(!empty($name)) $icon_name_array['bookmark'][$name] = array('balloon_name' => $bookmark_balloon_name_array[$name], 'sidename' => $bookmark_sidename_array[$name]);
		
	foreach($icon_name_array['RSS']['name'] as $name)
		if(!empty($name)) $icon_name_array['RSS'][$name] = array('balloon_name' => $RSS_balloon_name_array[$name], 'sidename' => $RSS_sidename_array[$name]);
		
	foreach($icon_name_array['blog']['name'] as $name)
		if(!empty($name)) $icon_name_array['blog'][$name] = array('balloon_name' => $blog_balloon_name_array[$name], 'sidename' => $blog_sidename_array[$name]);

	foreach($icon_name_array['mail']['name'] as $name)
		if(!empty($name)) $icon_name_array['mail'][$name] = array('balloon_name' => $mail_balloon_name_array[$name], 'sidename' => $mail_sidename_array[$name]);

	foreach($icon_name_array['messenger']['name'] as $name)
		if(!empty($name)) $icon_name_array['messenger'][$name] = array('balloon_name' => $messenger_balloon_name_array[$name], 'sidename' => $messenger_sidename_array[$name]);

	foreach($icon_name_array['more']['name'] as $name)
		if(!empty($name)) $icon_name_array['more'][$name] = array('balloon_name' => $more_balloon_name_array[$name], 'sidename' => $more_sidename_array[$name]);
}


function SNS_icons_Config($plugin) {
	icon_name_array($icon_name_array);

	$position_array = array('onTop', 'onBottom', 'onSidebar', 'onTag');
	$position_name_array = array('onTop'=>'본문 위', 'onBottom'=>'본문 아래', 'onSidebar'=>'옆막대', 'onTag'=>'치환자');

	$manifest = '
<config dataValHandler = "SNS_icons_DataSet">
	<window width="560" height="700" />
	<fieldset legend="HTML/CSS 설정">
		<field title="단추 넣을 곳(HTML) :" type="checkbox" name="positions">
			<op name="onTop" value="1"><![CDATA[본문 위]]></op>
			<op name="onBottom" value="1" checked="checked"><![CDATA[본문 아래]]></op>
		</field>
		<field title="CSS 넣기 :" type="checkbox" name="SNS_icon_css">'.CRLF;
	foreach($position_array as $position) {
		$manifest .= '			<op name="'.$position.'_css" value="1" checked="checked"><![CDATA['.$position_name_array[$position].']]></op>'.CRLF;
		if($position == "onTag") break;
	}
	$manifest .= '			<caption><![CDATA[※ HTML만 넣고 CSS를 넣지 않으면 글단추는 보이지만 쪽그림 단추는 보이지 않습니다.<br />
			※ 텍스트큐브 1.10 이상에서는 이동기기 화면에 단추를 넣을 수 없습니다.
			※ 이동기기 화면의 단추는 따로 설정하지 않아도 CSS가 들어갑니다.]]></caption>
		</field>
	</fieldset>

	<fieldset legend="글 보내기 설정">
		<field title="블로그 이름 넣기 :" name="blog_title_position" type="radio">
			<op value="none" checked="checked"><![CDATA[넣지 않음]]></op>
			<op value="fore"><![CDATA[글 제목 앞에]]></op>
			<op value="back"><![CDATA[글 제목 뒤에]]></op>
		</field>
		<field title="블로그 이름과 글 제목 사이에 넣을 기호 :" name="blog_title_division" type="text" size="5" value="" titledirection="">
			<caption><![CDATA[
			※ 비워 두면 " :: "이 들어갑니다.
			]]></caption>
		</field>
		<field title="연결할 글 주소 :" name="post_url" type="radio">
			<op value="1" checked="checked"><![CDATA[공개 주소]]></op>
			<op value="2"><![CDATA[숫자 주소]]></op>
			<caption><![CDATA[
			※ 숫자 주소를 고르면 블로그에서 제목 주소를 공개하더라도 숫자 주소로 잇습니다.<br />
			※ 트위터를 비롯한 몇몇 SNS에서는 한글이 섞인 제목 주소를 제대로 받지 못할 수 있습니다.
			]]></caption>
		</field>
		<field title="짧은 주소 :" name="short_url" type="select">
			<op value="none" checked="checked"><![CDATA[쓰지 않음]]></op>
			<op value="other"><![CDATA[다른 주소]]></op>
			<op value="bit.ly"><![CDATA[bit.ly]]></op>
			<op value="j.mp"><![CDATA[j.mp]]></op>
			<op value="is.gd"><![CDATA[is.gd]]></op>
			<op value="v.gd"><![CDATA[v.gd]]></op>
			<op value="to.ly"><![CDATA[to.ly]]></op>
			<op value="dok.do"><![CDATA[dok.do]]></op>
			<op value="goo.gl"><![CDATA[goo.gl]]></op>
			<op value="durl.me"><![CDATA[durl.me]]></op>
			<caption><![CDATA[※ 여기에서 지정한 짧은 주소는 글 길이를 제한하는 쪽글에 들어갑니다.]]></caption>
		</field>
		<field title="다른 주소 :" name="other_url" type="text" size="25" value="">
			<caption><![CDATA[※ 다른 주소는 블로그 기본 주소만 갈음하고 나머지 글 주소는 그대로 씁니다.<br />※ 다른 도메인 주소는 // 또는 http:// 또는 https://를 붙여야 합니다.]]></caption>
		</field>
		<field title="트위터 via 아이디 :" name="twitter_via_id" type="text" size="10" value="">
			<caption><![CDATA[※ 트위터 via 아이디를 넣으면 뒤쪽에 \'@아이디 에서\'가 붙습니다.]]></caption>
		</field>
	</fieldset>
	
	<fieldset legend="OpenGraph 메타 정보">
		<field title="메타 태그 넣기 :" type="checkbox" name="meta_info">
			<op name="meta_type" value="1"><![CDATA[og:type (=article)]]></op>
			<op name="meta_url" value="1"><![CDATA[og:url (글 주소)]]></op>
			<op name="meta_blog_title" value="1"><![CDATA[og:site_name (블로그 이름)]]></op>
			<op name="meta_post_title" value="1"><![CDATA[og:title (글 제목)]]></op>
 			<op name="meta_description" value="1"><![CDATA[og:description (글머리)]]></op>
 			<op name="image_src" value="1"><![CDATA[og:image (미리보기 그림)]]></op>
		</field>
		<field title="글머리 길이 :" name="beginning_length" type="text" size="5" value="150" titledirection="">
			<caption><![CDATA[
			<p>※ og:image로 앞세울 미리보기 그림은 [##_featured_image|123456789.gif_##] 꼴로 된 치환자를 글에 넣어 따로 지정할 수 있습니다. (블로그에 올린 파일만 따로 지정할 수 있음)</p><br />
			<p>※ 치환자가 없으면 글에 나오는 첫 그림을 og:image로 앞세웁니다.</p>
			]]></caption>
		</field>
	</fieldset>

	<fieldset legend="쪽그림 파일 경로">
		<field title=" " name="icon_path" type="text" size="65" value="http://">
			<caption><![CDATA[※ 다른 경로에서 쪽그림 파일을 불러오게 하여 전송량을 분산할 수 있습니다.]]></caption>
		</field>
	</fieldset>

	<fieldset legend="더 보기 창">
		<field title="가로 항목 수 :" name="more_x_item_num" type="text" size="2" value="2" titledirection="" />
		<field title="항목 하나의 가로 너비(px) :" name="more_item_name_width" type="text" size="3" value="100" titledirection="" />
		<field title="가로 위치 :" name="more_layer_horizontal_position" type="radio">
			<op value="left" checked="checked"><![CDATA[더 보기 단추 왼쪽]]></op>
			<op value="right"><![CDATA[더 보기 단추 오른쪽]]></op>
		</field>
	
		<field title="가로 위치 조절(px) :" name="more_x_correction" type="text" size="4" value="" titledirection="" />
	</fieldset>'.CRLF;

	foreach($position_array as $position) {
		$position_name = $position_name_array[$position];
		$manifest .= '
	<fieldset legend="'.$position_name.' - 단추 꾸미기">'.CRLF;
		foreach($icon_name_array['category'] as $category) {
			if($category == 'SNS1') $category_name = '나라 밖 SNS';
			else if($category == 'SNS2') $category_name = '나라 안 SNS';
			else if($category == 'bookmark') $category_name = '즐겨찾기/적어두기';
			else if($category == 'media_sharing') continue;
			else if($category == 'RSS') continue; //$category_name = $category;
			else if($category == 'blog') $category_name = '블로그';
			else if($category == 'mail') $category_name = '전자우편';
			else if($category == 'messenger') $category_name = '쪽글 나르개';
			else if($category == 'more') break;
			else $category_name = $category;
			$manifest .= '
		<field title="'.$category_name.' :" type="checkbox" name="buttons">';
			$i=0;
			foreach($icon_name_array[$category]['name'] as $name) {
				if(!$name) continue;
				$sidename = $icon_name_array[$category][$name]['sidename'];
				if($category == "bookmark" && $name != "bookmark") $sidename = str_replace($category_name, '', $sidename);
				$manifest .= '
			<op name="'.$position.'_'.$name.'" value="1"'.($category=="SNS" && $i++<3 ? ' checked="checked"' : '').'><![CDATA['.$sidename.']]></op>';
			}
			$manifest .= '
		</field>';
		}

		$manifest .= '
		<field title="더 보기 :" type="checkbox" name="buttons">
			<op name="'.$position.'_more" value="1" checked="checked"></op>
		</field>
		<field title="단추 크기/모양 :" name="'.$position.'_type" type="select">
			<op value="32x32"><![CDATA[32x32 쪽그림]]></op>
		  <op value="24x24" checked="checked"><![CDATA[24x24 쪽그림]]></op>
			<op value="16x16"><![CDATA[16x16 쪽그림]]></op>
			<op value="text"><![CDATA[글 단추]]></op>
		</field>
		<field title="가로 정렬 :" name="'.$position.'_align" type="radio">
			<op value="left"><![CDATA[왼쪽]]></op>
	 		<op value="center"><![CDATA[가운데]]></op>
			<op value="right" checked="checked"><![CDATA[오른쪽]]></op>
			<op value="none"><![CDATA[정렬하지 않음]]></op>
		</field>
		<field title=": 단추 가로 간격" name="'.$position.'_icon_interval" type="text" size="4" value="5" titledirection="bk" />
		<field title=": 단추 줄 간격" name="'.$position.'_icon_line_height" type="text" size="4" value="5" titledirection="bk" />
		<field title="쪽그림 이름 :" name="'.$position.'_sidename_position" type="radio">
			<op value="none" checked="checked"><![CDATA[넣지 않음]]></op>
			<op value="right"><![CDATA[오른쪽]]></op>
			<op value="bottom"><![CDATA[아래]]></op>
		</field>
		<field title="쪽그림 이름 글꼴 크기 :" name="'.$position.'_sidename_font_size" type="text" size="4" value="11" />
		<field title="쪽그림 이름 글꼴 색 : #" name="'.$position.'_sidename_font_color" type="text" size="7" value="" />
		<field title="쪽그림 이름 가로폭 :" name="'.$position.'_sidename_width" type="text" size="4" value="0" />
		<field title="쪽그림과 이름 간격 :" name="'.$position.'_sidename_margin" type="text" size="4" value="5" />
		<field title=": 위쪽 여백" name="'.$position.'_margin_top" type="text" size="5" value="10" titledirection="bk" />
		<field title=": 아래쪽 여백" name="'.$position.'_margin_bottom" type="text" size="5" value="10" titledirection="bk" />
		<field title=": 왼쪽 여백" name="'.$position.'_margin_left" type="text" size="5" value="0" titledirection="bk" />
		<field title=": 오른쪽 여백" name="'.$position.'_margin_right" type="text" size="5" value="0" titledirection="bk">
			<caption><![CDATA[※ 여백, 간격, 글꼴 크기에 단위(px, pt, mm, ...)를 넣지 않으면 px를 단위로 붙입니다.]]></caption>
		</field>

		<field title="'.$position_name.' - 단추 머리글 (Header)" name="'.$position.'_header" type="textarea" rows="3" cols="57">';
		if(substr($position,-7,7)=="Sidebar") $manifest .= '		<![CDATA[<div class="SNS_icons" class="widget"><h3>SNS 계정</h3>]]>';
		$manifest .= '		</field>
		<field title="'.$position_name.' - 단추 꼬리글 (Footer)" name="'.$position.'_footer" type="textarea" rows="2" cols="57">';
		if(substr($position,-7,7)=="Sidebar") $manifest .= '		<![CDATA[</div>]]>';
		$manifest .= '
		</field>
	</fieldset>';
	}
	$manifest .= '
</config>';

	return $manifest;
}


function SNS_icons_DataSet($data){
	$cfg = Setting::fetchConfigVal($data);
	return true;
}

?>